@@ -1,21 +1,10 @@
-/***************************************************************************
-
-    Copyright 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "parleydocument.h"
 
-#include <config-parley.h>
 #include "parleymainwindow.h"
 #include "editor/editor.h"
 #include "prefs.h"
@@ -39,7 +28,6 @@
 #else
 #include <KNS3/QtQuickDialogWrapper>
 #endif
-#include <kns3/uploaddialog.h>
 #include <KEMailSettings>
 #include <KMessageBox>
 #include <KProcess>
@@ -618,43 +606,6 @@ void ParleyDocument::languageProperties()
     }
 }
 
-void ParleyDocument::uploadFile()
-{
-    // save file to temp location
-    QTemporaryDir dir;
-    if ( ! dir.isValid() ) {
-        KMessageBox::error(m_parleyApp, i18n("Could not create temporary directory \"%1\"", dir.path() ));
-        return;
-    }
-    QUrl url(QUrl::fromUserInput(dir.path() + m_doc->url().fileName()) );
-    qDebug() << "save in " << url;
-    m_doc->setGenerator(QStringLiteral("Parley"));
-    if ( m_doc->saveAs(url, KEduVocDocument::Automatic) != KEduVocDocument::NoError ){
-        KMessageBox::error(m_parleyApp, i18n("Could not save vocabulary collection \"%1\"", url.toString() ));
-        return;
-    }
-
-    KEduVocDocument tempDoc(this);
-    if ( tempDoc.open(url) != KEduVocDocument::NoError ) {
-        KMessageBox::error(m_parleyApp, i18n("Could not open vocabulary collection \"%1\"", url.toString() ));
-        return;
-    }
-
-    // remove grades
-    tempDoc.lesson()->resetGrades(-1, KEduVocContainer::Recursive);
-    m_doc->setGenerator(QStringLiteral("Parley"));
-    if ( tempDoc.saveAs(url, KEduVocDocument::Automatic) != KEduVocDocument::NoError ) {
-        KMessageBox::error(m_parleyApp, i18n("Could not save vocabulary collection \"%1\"", url.toString() ));
-        return;
-    }
-
-    // upload
-    KNS3::UploadDialog dialog(ParleyMainWindow::instance());
-    dialog.setUploadFile(url);
-    dialog.exec();
-}
-
-
 void ParleyDocument::exportDialog()
 {
 #ifdef HAVE_LIBXSLT
